package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.mapper.HyjlMapper;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Hyjl;
import com.ruoyi.system.service.IHyjlService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 会议记录Controller
 * 
 * @author ruoyi
 * @date 2024-10-30
 */
@RestController
@RequestMapping("/system/hyjl")
public class HyjlController extends BaseController
{
    @Autowired
    private IHyjlService hyjlService;

    @Autowired
    private HyjlMapper hyjlMapper;
    /**
     * 查询会议记录列表
     */
    //@PreAuthorize("@ss.hasPermi('system:hyjl:list')")
    @GetMapping("/list")
    public TableDataInfo list(Hyjl hyjl)
    {
        startPage();
        List<Hyjl> list = hyjlService.selectHyjlList(hyjl);
        return getDataTable(list);
    }

    /**
     * 导出会议记录列表
     */
    //@PreAuthorize("@ss.hasPermi('system:hyjl:export')")
    @Log(title = "会议记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Hyjl hyjl)
    {
        List<Hyjl> list = hyjlService.selectHyjlList(hyjl);
        ExcelUtil<Hyjl> util = new ExcelUtil<Hyjl>(Hyjl.class);
        util.exportExcel(response, list, "会议记录数据");
    }

    /**
     * 获取会议记录详细信息
     */
    //@PreAuthorize("@ss.hasPermi('system:hyjl:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(hyjlService.selectHyjlById(id));
    }

    /**
     * 新增会议记录
     */
    //@PreAuthorize("@ss.hasPermi('system:hyjl:add')")
    @Log(title = "会议记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Hyjl hyjl)
    {
        hyjl.setCjsj2(DateUtils.dateTimeNow("yyyy-MM-dd"));
        Hyjl hl=hyjlMapper.selectHyjlOne(hyjl);
        if(hl!=null){
            return AjaxResult.error("已有参会记录，不允许重复提交");
        }
        return toAjax(hyjlService.insertHyjl(hyjl));
    }

    /**
     * 修改会议记录
     */
    //@PreAuthorize("@ss.hasPermi('system:hyjl:edit')")
    @Log(title = "会议记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Hyjl hyjl)
    {
        return toAjax(hyjlService.updateHyjl(hyjl));
    }

    /**
     * 删除会议记录
     */
    //@PreAuthorize("@ss.hasPermi('system:hyjl:remove')")
    @Log(title = "会议记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(hyjlService.deleteHyjlByIds(ids));
    }
}
